.. _lionagi-docs-index:

=================================
LionAGI — Documentation Home Page
=================================

Welcome to LionAGI's documentation!

Here you'll find:

* Core messages system (actions, etc.)
* Adapters (tools for conversions)
* Operatives (instruct, plans, etc.)
* Additional modules references
* High-level operations and strategies
* And more...

Contents
========

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents:

   tutorials/index
   modules/index
   operations/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
